@@ -253,6 +253,7 @@ fn t() {
             [
                 Synset {
                     id: "ewn-00001740-a",
+                    part_of_speech: Adjective,
                     definitions: [
                         "(usually followed by `to\') having the necessary means or skill or know-how or authority to do something",
                     ],
@@ -275,6 +276,7 @@ fn t() {
                 },
                 Synset {
                     id: "ewn-00001740-n",
+                    part_of_speech: Noun,
                     definitions: [
                         "that which is perceived or known or inferred to have its own distinct existence (living or nonliving)",
                     ],
@@ -296,6 +298,7 @@ fn t() {
                 },
                 Synset {
                     id: "ewn-00001740-r",
+                    part_of_speech: Adverb,
                     definitions: [
                         "without musical accompaniment",
                     ],
@@ -306,6 +309,7 @@ fn t() {
                 },
                 Synset {
                     id: "ewn-00001740-v",
+                    part_of_speech: Verb,
                     definitions: [
                         "draw air into, and expel out of, the lungs",
                     ],
@@ -374,6 +378,7 @@ fn t() {
                 },
                 Synset {
                     id: "ewn-00001885-r",
+                    part_of_speech: Adverb,
                     definitions: [
                         "in the Christian era; used before dates after the supposed year Christ was born",
                     ],
@@ -392,6 +397,7 @@ fn t() {
             [
                 Synset {
                     id: "ewn-92471097-n",
+                    part_of_speech: Noun,
                     definitions: [
                         "an art style in late 16th century Europe characterized by spatial incongruity and excessive elongation of the human figures.",
                     ],
@@ -407,6 +413,7 @@ fn t() {
                 },
                 Synset {
                     id: "ewn-92471179-n",
+                    part_of_speech: Noun,
                     definitions: [
                         "a surface generated by a moving straight line with the result that through every point on the surface a line can be drawn lying wholly in the surface.",
                     ],
@@ -422,6 +429,7 @@ fn t() {
                 },
                 Synset {
                     id: "ewn-92471253-n",
+                    part_of_speech: Noun,
                     definitions: [
                         "a pentagon in which the angles are all equal, and the sides all equal.",
                     ],
@@ -441,6 +449,7 @@ fn t() {
                 },
                 Synset {
                     id: "ewn-92767020-n",
+                    part_of_speech: Noun,
                     definitions: [
                         "an electrical device used to create artificial light by use of an electric lamp; all light fixtures have a fixture body and a light socket to hold the lamp and allow for its replacement",
                     ],
@@ -458,6 +467,7 @@ fn t() {
                 },
                 Synset {
                     id: "ewn-92767095-n",
+                    part_of_speech: Noun,
                     definitions: [
                         "a trained person hired to determine the sex of chicken and other hatchlings.",
                     ],
